@@ -21,7 +21,6 @@
  *
  * Ephy port by Marco Pesenti Gritti <marco@it.gnome.org>
  * 
- * $Id$
  */
 
 #ifndef COMPILING_TESTSPINNER
@@ -599,7 +598,7 @@ ephy_spinner_init (EphySpinner *spinner)
 
 	details = spinner->details = EPHY_SPINNER_GET_PRIVATE (spinner);
 
-	GTK_WIDGET_SET_FLAGS (GTK_WIDGET (spinner), GTK_NO_WINDOW);
+	gtk_widget_set_has_window (GTK_WIDGET (spinner), FALSE);
 
 	details->cache = ephy_spinner_cache_ref ();
 	details->size = GTK_ICON_SIZE_DIALOG;
@@ -615,12 +614,14 @@ ephy_spinner_expose (GtkWidget *widget,
 	EphySpinner *spinner = EPHY_SPINNER (widget);
 	EphySpinnerDetails *details = spinner->details;
 	EphySpinnerImages *images;
+	GtkAllocation allocation;
 	GdkPixbuf *pixbuf;
+	GdkWindow *window;
 	GdkGC *gc;
 	int x_offset, y_offset, width, height;
 	GdkRectangle pix_area, dest;
 
-	if (!GTK_WIDGET_DRAWABLE (spinner))
+	if (!gtk_widget_is_drawable (GTK_WIDGET (spinner)))
 	{
 		return FALSE;
 	}
@@ -651,11 +652,12 @@ ephy_spinner_expose (GtkWidget *widget,
 	height = gdk_pixbuf_get_height (pixbuf);
 
 	/* Compute the offsets for the image centered on our allocation */
-	x_offset = (widget->allocation.width - width) / 2;
-	y_offset = (widget->allocation.height - height) / 2;
+	gtk_widget_get_allocation (widget, &allocation);
+	x_offset = (allocation.width - width) / 2;
+	y_offset = (allocation.height - height) / 2;
 
-	pix_area.x = x_offset + widget->allocation.x;
-	pix_area.y = y_offset + widget->allocation.y;
+	pix_area.x = x_offset + allocation.x;
+	pix_area.y = y_offset + allocation.y;
 	pix_area.width = width;
 	pix_area.height = height;
 
@@ -664,10 +666,11 @@ ephy_spinner_expose (GtkWidget *widget,
 		return FALSE;
 	}
 
-	gc = gdk_gc_new (widget->window);
-	gdk_draw_pixbuf (widget->window, gc, pixbuf,
-			 dest.x - x_offset - widget->allocation.x,
-			 dest.y - y_offset - widget->allocation.y,
+	window = gtk_widget_get_window (widget);
+	gc = gdk_gc_new (window);
+	gdk_draw_pixbuf (window, gc, pixbuf,
+			 dest.x - x_offset - allocation.x,
+			 dest.y - y_offset - allocation.y,
 			 dest.x, dest.y,
 			 dest.width, dest.height,
 			 GDK_RGB_DITHER_MAX, 0, 0);
@@ -700,35 +703,6 @@ bump_spinner_frame_cb (EphySpinner *spinner)
 	return TRUE;
 }
 
-/**
- * ephy_spinner_start:
- * @spinner: a #EphySpinner
- *
- * Start the spinner animation.
- **/
-void
-ephy_spinner_start (EphySpinner *spinner)
-{
-	EphySpinnerDetails *details = spinner->details;
-
-	details->spinning = TRUE;
-
-	if (GTK_WIDGET_MAPPED (GTK_WIDGET (spinner)) &&
-	    details->timer_task == 0 &&
-	    ephy_spinner_load_images (spinner))
-	{
-		/* the 0th frame is the 'rest' icon */
-		details->current_image = MIN (1, details->images->n_animation_pixbufs);
-
-		details->timer_task =
-			g_timeout_add_full (G_PRIORITY_LOW,
-			                    details->timeout,
-				            (GSourceFunc) bump_spinner_frame_cb,
-				            spinner,
-				            NULL);
-	}
-}
-
 static void
 ephy_spinner_remove_update_callback (EphySpinner *spinner)
 {
@@ -741,57 +715,6 @@ ephy_spinner_remove_update_callback (EphySpinner *spinner)
 	}
 }
 
-/**
- * ephy_spinner_stop:
- * @spinner: a #EphySpinner
- *
- * Stop the spinner animation.
- **/
-void
-ephy_spinner_stop (EphySpinner *spinner)
-{
-	EphySpinnerDetails *details = spinner->details;
-
-	details->spinning = FALSE;
-	details->current_image = 0;
-
-	if (details->timer_task != 0)
-	{
-		ephy_spinner_remove_update_callback (spinner);
-
-		if (GTK_WIDGET_MAPPED (GTK_WIDGET (spinner)))
-		{
-			gtk_widget_queue_draw (GTK_WIDGET (spinner));
-		}
-	}
-}
-
-/*
- * ephy_spinner_set_size:
- * @spinner: a #EphySpinner
- * @size: the size of type %GtkIconSize
- *
- * Set the size of the spinner.
- **/
-void
-ephy_spinner_set_size (EphySpinner *spinner,
-		       GtkIconSize size)
-{
-	if (size == GTK_ICON_SIZE_INVALID)
-	{
-		size = GTK_ICON_SIZE_DIALOG;
-	}
-
-	if (size != spinner->details->size)
-	{
-		ephy_spinner_unload_images (spinner);
-
-		spinner->details->size = size;
-
-		gtk_widget_queue_resize (GTK_WIDGET (spinner));
-	}
-}
-
 #if 0
 /*
  * ephy_spinner_set_timeout:
@@ -957,14 +880,97 @@ ephy_spinner_class_init (EphySpinnerClass *class)
 	g_type_class_add_private (object_class, sizeof (EphySpinnerDetails));
 }
 
-/*
+/**
+ * ephy_spinner_start:
+ * @spinner: an #EphySpinner
+ *
+ * Starts the spinner animation.
+ **/
+void
+ephy_spinner_start (EphySpinner *spinner)
+{
+	EphySpinnerDetails *details = spinner->details;
+
+	details->spinning = TRUE;
+
+	if (GTK_WIDGET_MAPPED (GTK_WIDGET (spinner)) &&
+	    details->timer_task == 0 &&
+	    ephy_spinner_load_images (spinner))
+	{
+		/* the 0th frame is the 'rest' icon */
+		details->current_image = MIN (1, details->images->n_animation_pixbufs);
+
+		details->timer_task =
+			g_timeout_add_full (G_PRIORITY_LOW,
+			                    details->timeout,
+				            (GSourceFunc) bump_spinner_frame_cb,
+				            spinner,
+				            NULL);
+	}
+}
+
+/**
+ * ephy_spinner_stop:
+ * @spinner: an #EphySpinner
+ *
+ * Stops the spinner animation.
+ *
+ **/
+void
+ephy_spinner_stop (EphySpinner *spinner)
+{
+	EphySpinnerDetails *details = spinner->details;
+
+	details->spinning = FALSE;
+	details->current_image = 0;
+
+	if (details->timer_task != 0)
+	{
+		ephy_spinner_remove_update_callback (spinner);
+
+		//if (GTK_WIDGET_MAPPED (GTK_WIDGET (spinner)))
+		{
+			gtk_widget_queue_draw (GTK_WIDGET (spinner));
+		}
+	}
+}
+
+/**
+ * ephy_spinner_set_size:
+ * @spinner: an #EphySpinner
+ * @size: a new size for the spinner, as a #GtkIconSize
+ *
+ * Set the size of the spinner to @size.
+ *
+ **/
+void
+ephy_spinner_set_size (EphySpinner *spinner,
+		       GtkIconSize size)
+{
+	if (size == GTK_ICON_SIZE_INVALID)
+	{
+		size = GTK_ICON_SIZE_DIALOG;
+	}
+
+	if (size != spinner->details->size)
+	{
+		ephy_spinner_unload_images (spinner);
+
+		spinner->details->size = size;
+
+		gtk_widget_queue_resize (GTK_WIDGET (spinner));
+	}
+}
+
+/**
  * ephy_spinner_new:
  *
- * Create a new #EphySpinner. The spinner is a widget
+ * Creates a new #EphySpinner. The spinner is a widget
  * that gives the user feedback about network status with
  * an animated image.
  *
- * Return Value: the spinner #GtkWidget
+ * Returns: the spinner #GtkWidget
+ *
  **/
 GtkWidget *
 ephy_spinner_new (void)
