@@ -16,13 +16,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error "Only <epiphany/epiphany.h> can be included directly."
+#endif
+
 #ifndef EPHY_FULLSCREEN_POPUP_H
 #define EPHY_FULLSCREEN_POPUP_H
 
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include "ephy-window.h"
 
 G_BEGIN_DECLS
