@@ -15,22 +15,18 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-net-monitor.c 7535 2007-10-18 19:15:05Z cosimoc $
  */
 
 #include "config.h"
 
 #include "ephy-net-monitor.h"
 
-#include "ephy-dbus.h"
-#include "ephy-shell.h"
-#include "ephy-session.h"
-#include "ephy-embed-single.h"
 #include "eel-gconf-extensions.h"
-#include "ephy-prefs.h"
+#include "ephy-dbus.h"
 #include "ephy-debug.h"
+#include "ephy-prefs.h"
 
-#include <NetworkManager/NetworkManager.h>
+#include <NetworkManager.h>
 
 #include <gmodule.h>
 
@@ -56,7 +52,7 @@ enum
 	PROP_NETWORK_STATUS
 };
 
-static GObjectClass *parent_class;
+G_DEFINE_TYPE (EphyNetMonitor, ephy_net_monitor, G_TYPE_OBJECT)
 
 static void
 ephy_net_monitor_set_net_status (EphyNetMonitor *monitor,
@@ -130,7 +126,9 @@ ephy_net_monitor_check_network (EphyNetMonitor *monitor)
 
 	if (dbus_connection_send_with_reply (priv->bus, message, &reply, -1)) 
 	{
-		dbus_pending_call_set_notify (reply, ephy_net_monitor_dbus_notify, monitor, NULL);
+		dbus_pending_call_set_notify (reply,
+					      (DBusPendingCallNotifyFunction)ephy_net_monitor_dbus_notify,
+					      monitor, NULL);
 		dbus_pending_call_unref (reply);
 	}
 	
@@ -331,7 +329,7 @@ ephy_net_monitor_dispose (GObject *object)
 		priv->notify_id = 0;
 	}
 
-	parent_class->dispose (object);
+	G_OBJECT_CLASS (ephy_net_monitor_parent_class)->dispose (object);
 }
 
 static void
@@ -355,8 +353,6 @@ ephy_net_monitor_class_init (EphyNetMonitorClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class->dispose = ephy_net_monitor_dispose;
 	object_class->get_property = ephy_net_monitor_get_property;
 
@@ -379,34 +375,6 @@ ephy_net_monitor_class_init (EphyNetMonitorClass *klass)
 
 /* public API */
 
-GType
-ephy_net_monitor_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo our_info =
-		{
-			sizeof (EphyShellClass),
-			NULL, /* base_init */
-			NULL, /* base_finalize */
-			(GClassInitFunc) ephy_net_monitor_class_init,
-			NULL,
-			NULL, /* class_data */
-			sizeof (EphyNetMonitor),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) ephy_net_monitor_init
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "EphyNetMonitor",
-					       &our_info, 0);
-	}
-
-	return type;
-}
-
 EphyNetMonitor *
 ephy_net_monitor_new (void)
 {
